"""
Core package

"""

from .client import Client

__all__ = ("Client",)
